==> skypager-project-2.56.0.tgz: package/src/assets/settings_file.js <==
import DataSource from './data_source'

import get from 'lodash/get'
import clone from 'lodash/clone'
import omit from 'lodash/omit'
import omitBy from 'lodash/omitBy'
import result from 'lodash/result'
import defaults from 'lodash/defaultsDeep'

const EXTENSIONS = ['js', 'json', 'yaml', 'yml', 'csv']
const GLOB = '**/*.{' + EXTENSIONS.join(',') + '}'

export class SettingsFile extends DataSource {

  static EXTENSIONS = EXTENSIONS;
  static GLOB = GLOB;

  static decorateCollection(collection, options = {}) {
    defineProperty(collection, 'notSecret', {
       enumerable: true,
       configurable: false,
       get: function(){
         return collection.where(file => {
            return !file.id.match(/(secret|secure|private|hidden)/i)
         })
       }
    })

    defineProperty(collection, 'resolvePath', {
       enumerable: true,
       configurable: false,
       value: function(path){
         var parts = path.split('.')

         let match

         while(!match && parts.length > 0) {
           match = collection.at(parts.join('/'))
           parts.pop()
         }

         return match
       }
    })
  }

  constructor (uri, options = {}) {
    super(uri, options)

    this.indexer = parseSettings.bind(this)
  }

  set(key, value) {
    if (!value && isObject(key)) {
      Object.keys(key).forEach(k => {
        this.set(k, key[k])
      })
      return this
    }

    if(isString(key) && !key.match(/(secret|secure|secured|hidden|private)/i)) {
      if(get(this.indexed, `${ this.project.env }.${ key }`)) {
        key = `${ this.project.env }.${ key }`
      }

      set(this.parsed, key, value)
    }

    return this
  }
  /*
   * This lets us write less nested
   * versions of a settings file
   */
  getData() {
    if (this.extension !== '.js' && (!this.raw || this.raw.length === 0)) {
      this.runImporter('disk', {asset: this, sync: true})
    }

    let value = this.indexed
    let parts = this.id.split('/')
    let last = parts[ parts.length - 1]

    /**
     * If the settings yaml has a single key whose value
     * is the name of the settings file, we will use the value
     * at that key instead of the redundant nesting
     */
    if (value[last] && keys(value).length === 1) {
      value = value[last] || {}
    }

    if (get(value, this.project.env)) {
      value = get(value, this.project.env)
    }

    let settingsDefaults = (last !== 'defaults' && get(this.indexed, 'defaults', {}))

    value = omit(value, 'defaults')

    let data = settingsDefaults
      ? defaults({}, value, settingsDefaults)
      : value

    return omitBy(data, (v,k) => k.match(/(secure|secret|private|hidden)/i))
  }
}

export default SettingsFile

function interpolateValues (obj, template) {
  let datasource = this

  Object.keys(obj)
  .filter(key => !key.match(/(secret|secure|private|hidden)/i))
  .forEach(key => {
    let value = obj[key]

    if (typeof value === 'object') {
      interpolateValues.call(datasource, value, template)
    } else if (typeof value === 'string' && value.match(/^env\.\w+$/i)) {
      value = `<%= process.${ value } %>`
      obj[key] = template(value)(value)
    } else if (typeof value === 'string' ) {
      obj[key] = template(value)(value)
    }
  })

  return obj
}

function parseSettings (val = {}) {
  let base = interpolateValues.call(this, clone(val), this.templater.bind(this))

  return omitBy(base, (v,k) => {
     return k.match(/(secret|secure|hidden|private)/i)
  })
}

const { defineProperty, keys } = Object

==> skypager-project-2.60.1.tgz: package/src/assets/settings_file.js <==
import DataSource from './data_source'

import get from 'lodash/get'
import clone from 'lodash/clone'
import omit from 'lodash/omit'
import omitBy from 'lodash/omitBy'
import result from 'lodash/result'
import defaults from 'lodash/defaultsDeep'

const EXTENSIONS = ['js', 'json', 'yaml', 'yml', 'csv']
const GLOB = '**/*.{' + EXTENSIONS.join(',') + '}'
const SECRET_REGEX = /(secret|secure|secured|hidden|private)/i

export class SettingsFile extends DataSource {

  static EXTENSIONS = EXTENSIONS;
  static GLOB = GLOB;

  static decorateCollection(collection, options = {}) {
    defineProperty(collection, 'notSecret', {
       enumerable: true,
       configurable: false,
       get: function(){
         return collection.where(file => {
            return !file.id.match(SECRET_REGEX)
         })
       }
    })

    defineProperty(collection, 'resolvePath', {
       enumerable: true,
       configurable: false,
       value: function(path){
         var parts = path.split('.')

         let match

         while(!match && parts.length > 0) {
           match = collection.at(parts.join('/'))
           parts.pop()
         }

         return match
       }
    })
  }

  constructor (uri, options = {}) {
    super(uri, options)

    this.indexer = parseSettings.bind(this)
  }

  set(key, value) {
    if (!value && isObject(key)) {
      Object.keys(key).forEach(k => {
        this.set(k, key[k])
      })
      return this
    }

    if(isString(key) && !key.match(SECRET_REGEX)) {
      if(get(this.indexed, `${ this.project.env }.${ key }`)) {
        key = `${ this.project.env }.${ key }`
      }

      set(this.parsed, key, value)
    }

    return this
  }
  /*
   * This lets us write less nested
   * versions of a settings file
   */
  getData() {
    if (this.extension !== '.js' && (!this.raw || this.raw.length === 0)) {
      this.runImporter('disk', {asset: this, sync: true})
    }

    let value = this.indexed
    let parts = this.id.split('/')
    let last = parts[ parts.length - 1]

    /**
     * If the settings yaml has a single key whose value
     * is the name of the settings file, we will use the value
     * at that key instead of the redundant nesting
     */
    if (value[last] && keys(value).length === 1) {
      value = value[last] || {}
    }

    if (get(value, this.project.env)) {
      value = get(value, this.project.env)
    }

    let settingsDefaults = (last !== 'defaults' && get(this.indexed, 'defaults', {}))

    value = omit(value, 'defaults')

    let data = settingsDefaults
      ? defaults({}, value, settingsDefaults)
      : value

    return omitBy(data, (v,k) => k.match(SECRET_REGEX))
  }
}

export default SettingsFile

function interpolateValues (obj, template) {
  let datasource = this

  Object.keys(obj)
  .filter(key => !key.match(SECRET_REGEX))
  .forEach(key => {
    let value = obj[key]

    if (typeof value === 'object') {
      interpolateValues.call(datasource, value, template)
    } else if (typeof value === 'string' && value.match(/^env\.\w+$/i)) {
      value = `<%= process.${ value } %>`
      obj[key] = template(value)(value)
    } else if (typeof value === 'string' ) {
      obj[key] = template(value)(value)
    }
  })

  return obj
}

function parseSettings (val = {}) {
  let base = interpolateValues.call(this, clone(val), this.templater.bind(this))

  return omitBy(base, (v,k) => {
     return k.match(SECRET_REGEX)
  })
}

const { defineProperty, keys } = Object
